# Sample Package Data

This directory contains sample data to test out functions in metapredict. Notably, there isn't a lot of sample data you will need to use metapredict. Nonetheless, I included a .fasta file called test_data.fasta.